==> kleopatra-16.08.1.tar.xz: kleopatra-16.08.1/src/dialogs/adduseriddialog.h <==
/* -*- mode: c++; c-basic-offset:4 -*-
    dialogs/addUserIDdialog.h

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2008 Klarälvdalens Datakonsult AB

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEOPATRA_DIALOGS_ADDUSERIDDIALOG_H__
#define __KLEOPATRA_DIALOGS_ADDUSERIDDIALOG_H__

#include <QDialog>

#include <utils/pimpl_ptr.h>

class QString;

namespace Kleo
{
namespace Dialogs
{

class AddUserIDDialog : public QDialog
{
    Q_OBJECT
    Q_PROPERTY(QString name    READ name    WRITE setName)
    Q_PROPERTY(QString email   READ email   WRITE setEmail)
    Q_PROPERTY(QString comment READ comment WRITE setComment)
public:
    explicit AddUserIDDialog(QWidget *parent = Q_NULLPTR);
    ~AddUserIDDialog();

    void setName(const QString &name);
    QString name() const;

    void setEmail(const QString &email);
    QString email() const;

    void setComment(const QString &comment);
    QString comment() const;

private:
    class Private;
    kdtools::pimpl_ptr<Private> d;
    Q_PRIVATE_SLOT(d, void slotUserIDChanged())
};

}
}

#endif /* __KLEOPATRA_DIALOGS_ADDUSERIDDIALOG_H__ */

==> kleopatra-19.11.80.tar.xz: kleopatra-19.11.80/src/dialogs/adduseriddialog.h <==
/* -*- mode: c++; c-basic-offset:4 -*-
    dialogs/addUserIDdialog.h

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2008 Klarälvdalens Datakonsult AB

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEOPATRA_DIALOGS_ADDUSERIDDIALOG_H__
#define __KLEOPATRA_DIALOGS_ADDUSERIDDIALOG_H__

#include <QDialog>

#include <utils/pimpl_ptr.h>

class QString;

namespace Kleo
{
namespace Dialogs
{

class AddUserIDDialog : public QDialog
{
    Q_OBJECT
    Q_PROPERTY(QString name    READ name    WRITE setName)
    Q_PROPERTY(QString email   READ email   WRITE setEmail)
    Q_PROPERTY(QString comment READ comment WRITE setComment)
public:
    explicit AddUserIDDialog(QWidget *parent = nullptr);
    ~AddUserIDDialog();

    void setName(const QString &name);
    QString name() const;

    void setEmail(const QString &email);
    QString email() const;

    void setComment(const QString &comment);
    QString comment() const;

private:
    class Private;
    kdtools::pimpl_ptr<Private> d;
    Q_PRIVATE_SLOT(d, void slotUserIDChanged())
};

}
}

#endif /* __KLEOPATRA_DIALOGS_ADDUSERIDDIALOG_H__ */
